'''
Author: LetMeFly
Date: 2022-01-25 17:46:23
LastEditors: LetMeFly
LastEditTime: 2022-01-25 18:32:44
'''
from distutils.core import setup
from setuptools import find_packages

with open("Readme.rst", "r", encoding='utf-8') as f:
  long_description = f.read()

setup(name = 'BUCTOJ',  # 包名
    version = '0.0.1',  # 版本号
    description='用Python玩转北化OJ平台',
    long_description = long_description,
    author = 'LetMeFly',
    author_email='Tisfy@qq.com',
    url = 'https://letmefly.xyz/',
    install_requires=[
        'requests>=1.0.0',
        'lxml>=2.0',
        'beautifulsoup4>=4.0.1'
    ],
    license='Apache License',
    packages=find_packages(),
    platforms=["all"],
    classifiers=[
        'Intended Audience :: Developers',
        'Operating System :: OS Independent',
        'Natural Language :: Chinese (Simplified)',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Topic :: Software Development :: Libraries'
    ],
)



'''
Author: LetMeFly
Date: 2022-01-25 18:07:26
LastEditors: LetMeFly
LastEditTime: 2022-01-25 18:08:30
'''
__all__ = ['AutoGetAndSubmit', 'FromPidToChar', 'GetASourceCodeAndChange', 'GetContestProblemList', 'Login', 'SubmitOneCode']